==> cost-interface-0.1.1-sources.jar: com/chinayanghe/tpm/cost/vo/out/CostRegisterFormResVo.java <==

package com.chinayanghe.tpm.cost.vo.out;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 费用-登记单查询条件Vo对象
 * @author arthur
 *
 */
public  class CostRegisterFormResVo  implements Serializable{
	
    private Integer id;
    
    private List<CostRegisterItemResVo> itemList;

    /**
     * 单号
     */
    private String formNo;

    /**
     * 表单类型（登记-申请-核报）
     */
    private String formType;

    /**
     * 开始日期
     */
    private Date sDate;

    /**
     * 结束日期
     */
    private Date eDate;

    /**
     * 客户编号
     */
    private String kunnr;

    /**
     * 经销商一级渠道
     */
    private String level1Channel;

    /**
     * 经销商2级渠道
     */
    private String level2Channel;

    /**
     * 品牌大类
     */
    private String spart;

    /**
     * 活动类型编码
     */
    private String activityTypeCode;

    /**
     * 活动类型名称
     */
    private String activityTypeName;

    /**
     * 活动类型二级编码
     */
    private String activityTypeCodeSub;

    /**
     * 活动类型2级编码名称
     */
    private String activityTypeNameSub;

    /**
     * 经销商编号
     */
    private String dealerId;

    /**
     * 经销商名称
     */
    private String dealerName;

    /**
     * 
     * 表字段 : activity_base_info.dealer_type
     */
    private String dealerType;

    /**
     * 区域市场(行政区域，多个以，号分割)
     */
    private String regionMkt;

    /**
     * 城市经理编号
     */
    private String zcmId;

    /**
     * 城市经理名称
     */
    private String zcmName;

    /**
     * 特殊备注
     */
    private String speNotes;

    /**
     * 厂方承担金额(分)
     */
    private Long addAssumeAmt;

    /**
     * 活动金额(分)
     */
    private Long activityAmount;

    /**
     * 申请金额合计(分)
     */
    private Long applyAmount;

    /**
     * 核报金额合计(分)
     */
    private Long payAmount;

    /**
     * 审核金额合计(分)
     */
    private Long auditAmount;

    /**
     * 复核金额合计(分)
     */
    private Long reviewAmount;

    /**
     * 最终审核金额(分)
     */
    private Long finalAmount;

    /**
     * 促销类型
     */
    private String promoteType;

    /**
     * 是否个性化促销1是 0不是
     */
    private int isIndividualPromote;

    /**
     * 渠道
     * 表字段 : activity_base_info.channel
     */
    private String channel;

    /**
     * 账务处理方式（入账类型）
     */
    private String accountTreat;

    /**
     * 入帐经销商编号
     */
    private String entryDealerId;

    /**
     * 入帐经销商名称
     */
    private String entryDealerName;

    /**
     * 是否督查扣款
     */
    private int isPayment;


    /**
     * 
     * 表字段 : activity_base_info.status
     */
    private Integer status;

    /**
     * 
     * 表字段 : activity_base_info.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : activity_base_info.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : activity_base_info.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : activity_base_info.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : activity_base_info.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : activity_base_info.modify_date
     */
    private Date modifyDate;

    /**
     * 预估销量瓶数
     * 表字段 : activity_base_info.sale_forecast_num
     */
    private Integer saleForecastNum;

    /**
     * 预估销售金额
     * 表字段 : activity_base_info.sale_forecast_amount
     */
    private Long saleForecastAmount;

    /**
     * 是否促销(0是，1否)
     */
    private Byte isPromote;

    /**
     * 促销品采购方式
     */
    private String promoteProductBuyway;

    /**
     * 促销总金额(分)
     */
    private Integer promoteAmountTotal;

    /**
     * 登记意见
     */
    private String registNotes;

    /**
     * 活动投入实施说明
     */
    private String activityNotes;

    /**
     * 督查汇总意见
     */
    private String auditNotes;

    /**
     * 是否督查扣款
     */
    private int  idAuditWithhold;

	public Integer getId() {
		return id;
	}

	public void setId(Integer id) {
		this.id = id;
	}

	public String getFormNo() {
		return formNo;
	}

	public void setFormNo(String formNo) {
		this.formNo = formNo;
	}

	public String getFormType() {
		return formType;
	}

	public void setFormType(String formType) {
		this.formType = formType;
	}

	public Date getsDate() {
		return sDate;
	}

	public void setsDate(Date sDate) {
		this.sDate = sDate;
	}

	public Date geteDate() {
		return eDate;
	}

	public void seteDate(Date eDate) {
		this.eDate = eDate;
	}

	public String getKunnr() {
		return kunnr;
	}

	public void setKunnr(String kunnr) {
		this.kunnr = kunnr;
	}

	public String getLevel1Channel() {
		return level1Channel;
	}

	public void setLevel1Channel(String level1Channel) {
		this.level1Channel = level1Channel;
	}

	public String getLevel2Channel() {
		return level2Channel;
	}

	public void setLevel2Channel(String level2Channel) {
		this.level2Channel = level2Channel;
	}

	public String getSpart() {
		return spart;
	}

	public void setSpart(String spart) {
		this.spart = spart;
	}

	public String getActivityTypeCode() {
		return activityTypeCode;
	}

	public void setActivityTypeCode(String activityTypeCode) {
		this.activityTypeCode = activityTypeCode;
	}

	public String getActivityTypeName() {
		return activityTypeName;
	}

	public void setActivityTypeName(String activityTypeName) {
		this.activityTypeName = activityTypeName;
	}

	public String getActivityTypeCodeSub() {
		return activityTypeCodeSub;
	}

	public void setActivityTypeCodeSub(String activityTypeCodeSub) {
		this.activityTypeCodeSub = activityTypeCodeSub;
	}

	public String getActivityTypeNameSub() {
		return activityTypeNameSub;
	}

	public void setActivityTypeNameSub(String activityTypeNameSub) {
		this.activityTypeNameSub = activityTypeNameSub;
	}

	public String getDealerId() {
		return dealerId;
	}

	public void setDealerId(String dealerId) {
		this.dealerId = dealerId;
	}

	public String getDealerName() {
		return dealerName;
	}

	public void setDealerName(String dealerName) {
		this.dealerName = dealerName;
	}

	public String getDealerType() {
		return dealerType;
	}

	public void setDealerType(String dealerType) {
		this.dealerType = dealerType;
	}

	public String getRegionMkt() {
		return regionMkt;
	}

	public void setRegionMkt(String regionMkt) {
		this.regionMkt = regionMkt;
	}

	public String getZcmId() {
		return zcmId;
	}

	public void setZcmId(String zcmId) {
		this.zcmId = zcmId;
	}

	public String getZcmName() {
		return zcmName;
	}

	public void setZcmName(String zcmName) {
		this.zcmName = zcmName;
	}

	public String getSpeNotes() {
		return speNotes;
	}

	public void setSpeNotes(String speNotes) {
		this.speNotes = speNotes;
	}

	public Long getAddAssumeAmt() {
		return addAssumeAmt;
	}

	public void setAddAssumeAmt(Long addAssumeAmt) {
		this.addAssumeAmt = addAssumeAmt;
	}

	public Long getActivityAmount() {
		return activityAmount;
	}

	public void setActivityAmount(Long activityAmount) {
		this.activityAmount = activityAmount;
	}

	public Long getApplyAmount() {
		return applyAmount;
	}

	public void setApplyAmount(Long applyAmount) {
		this.applyAmount = applyAmount;
	}

	public Long getPayAmount() {
		return payAmount;
	}

	public void setPayAmount(Long payAmount) {
		this.payAmount = payAmount;
	}

	public Long getAuditAmount() {
		return auditAmount;
	}

	public void setAuditAmount(Long auditAmount) {
		this.auditAmount = auditAmount;
	}

	public Long getReviewAmount() {
		return reviewAmount;
	}

	public void setReviewAmount(Long reviewAmount) {
		this.reviewAmount = reviewAmount;
	}

	public Long getFinalAmount() {
		return finalAmount;
	}

	public void setFinalAmount(Long finalAmount) {
		this.finalAmount = finalAmount;
	}

	public String getPromoteType() {
		return promoteType;
	}

	public void setPromoteType(String promoteType) {
		this.promoteType = promoteType;
	}

	public int getIsIndividualPromote() {
		return isIndividualPromote;
	}

	public void setIsIndividualPromote(int isIndividualPromote) {
		this.isIndividualPromote = isIndividualPromote;
	}

	public String getChannel() {
		return channel;
	}

	public void setChannel(String channel) {
		this.channel = channel;
	}

	public String getAccountTreat() {
		return accountTreat;
	}

	public void setAccountTreat(String accountTreat) {
		this.accountTreat = accountTreat;
	}

	public String getEntryDealerId() {
		return entryDealerId;
	}

	public void setEntryDealerId(String entryDealerId) {
		this.entryDealerId = entryDealerId;
	}

	public String getEntryDealerName() {
		return entryDealerName;
	}

	public void setEntryDealerName(String entryDealerName) {
		this.entryDealerName = entryDealerName;
	}

	public int getIsPayment() {
		return isPayment;
	}

	public void setIsPayment(int isPayment) {
		this.isPayment = isPayment;
	}


	public Integer getStatus() {
		return status;
	}

	public void setStatus(Integer status) {
		this.status = status;
	}

	public String getCreateId() {
		return createId;
	}

	public void setCreateId(String createId) {
		this.createId = createId;
	}

	public String getCreateName() {
		return createName;
	}

	public void setCreateName(String createName) {
		this.createName = createName;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public String getModifyId() {
		return modifyId;
	}

	public void setModifyId(String modifyId) {
		this.modifyId = modifyId;
	}

	public String getModifyName() {
		return modifyName;
	}

	public void setModifyName(String modifyName) {
		this.modifyName = modifyName;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Integer getSaleForecastNum() {
		return saleForecastNum;
	}

	public void setSaleForecastNum(Integer saleForecastNum) {
		this.saleForecastNum = saleForecastNum;
	}

	public Long getSaleForecastAmount() {
		return saleForecastAmount;
	}

	public void setSaleForecastAmount(Long saleForecastAmount) {
		this.saleForecastAmount = saleForecastAmount;
	}

	public Byte getIsPromote() {
		return isPromote;
	}

	public void setIsPromote(Byte isPromote) {
		this.isPromote = isPromote;
	}

	public String getPromoteProductBuyway() {
		return promoteProductBuyway;
	}

	public void setPromoteProductBuyway(String promoteProductBuyway) {
		this.promoteProductBuyway = promoteProductBuyway;
	}

	public Integer getPromoteAmountTotal() {
		return promoteAmountTotal;
	}

	public void setPromoteAmountTotal(Integer promoteAmountTotal) {
		this.promoteAmountTotal = promoteAmountTotal;
	}

	public String getRegistNotes() {
		return registNotes;
	}

	public void setRegistNotes(String registNotes) {
		this.registNotes = registNotes;
	}

	public String getActivityNotes() {
		return activityNotes;
	}

	public void setActivityNotes(String activityNotes) {
		this.activityNotes = activityNotes;
	}

	public String getAuditNotes() {
		return auditNotes;
	}

	public void setAuditNotes(String auditNotes) {
		this.auditNotes = auditNotes;
	}

	public int getIdAuditWithhold() {
		return idAuditWithhold;
	}

	public void setIdAuditWithhold(int idAuditWithhold) {
		this.idAuditWithhold = idAuditWithhold;
	}

	public List<CostRegisterItemResVo> getItemList() {
		return itemList;
	}

	public void setItemList(List<CostRegisterItemResVo> itemList) {
		this.itemList = itemList;
	}
    
    
	
}

==> cost-interface-0.1.4-sources.jar: com/chinayanghe/tpm/cost/vo/out/CostRegisterFormResVo.java <==

package com.chinayanghe.tpm.cost.vo.out;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 费用-登记单查询条件Vo对象
 * @author arthur
 *
 */
public  class CostRegisterFormResVo  implements Serializable{
	
    private Integer id;
    
    private List<CostRegisterItemResVo> itemList;

    /** 标题*/
    private String title;
    /**
     * 单号
     */
    private String formNo;

    /**
     * 表单类型（登记-申请-核报）
     */
    private String formType;

    /**
     * 开始日期
     */
    private Date sDate;

    /**
     * 结束日期
     */
    private Date eDate;

    /**
     * 客户编号
     */
    private String kunnr;

    /**
     * 经销商一级渠道
     */
    private String level1Channel;

    /**
     * 经销商2级渠道
     */
    private String level2Channel;

    /**
     * 品牌大类
     */
    private String spart;

    /**
     * 活动类型编码
     */
    private String activityTypeCode;

    /**
     * 活动类型名称
     */
    private String activityTypeName;

    /**
     * 活动类型二级编码
     */
    private String activityTypeCodeSub;

    /**
     * 活动类型2级编码名称
     */
    private String activityTypeNameSub;

    /**
     * 经销商编号
     */
    private String dealerId;

    /**
     * 经销商名称
     */
    private String dealerName;

    /**
     * 
     * 表字段 : activity_base_info.dealer_type
     */
    private String dealerType;

    /**
     * 区域市场(行政区域，多个以，号分割)
     */
    private String regionMkt;

    /**
     * 城市经理编号
     */
    private String zcmId;

    /**
     * 城市经理名称
     */
    private String zcmName;

    /**
     * 特殊备注
     */
    private String speNotes;

    /**
     * 厂方承担金额(分)
     */
    private Long addAssumeAmt;

    /**
     * 活动金额(分)
     */
    private Long activityAmount;

    /**
     * 申请金额合计(分)
     */
    private Long applyAmount;

    /**
     * 核报金额合计(分)
     */
    private Long payAmount;

    /**
     * 审核金额合计(分)
     */
    private Long auditAmount;

    /**
     * 复核金额合计(分)
     */
    private Long reviewAmount;

    /**
     * 最终审核金额(分)
     */
    private Long finalAmount;

    /**
     * 促销类型
     */
    private String promoteType;

    /**
     * 是否个性化促销1是 0不是
     */
    private int isIndividualPromote;

    /**
     * 渠道
     * 表字段 : activity_base_info.channel
     */
    private String channel;

    /**
     * 账务处理方式（入账类型）
     */
    private String accountTreat;

    /**
     * 入帐经销商编号
     */
    private String entryDealerId;

    /**
     * 入帐经销商名称
     */
    private String entryDealerName;

    /**
     * 是否督查扣款
     */
    private int isPayment;


    /**
     * 
     * 表字段 : activity_base_info.status
     */
    private Integer status;

    /**
     * 
     * 表字段 : activity_base_info.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : activity_base_info.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : activity_base_info.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : activity_base_info.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : activity_base_info.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : activity_base_info.modify_date
     */
    private Date modifyDate;

    /**
     * 预估销量瓶数
     * 表字段 : activity_base_info.sale_forecast_num
     */
    private Integer saleForecastNum;

    /**
     * 预估销售金额
     * 表字段 : activity_base_info.sale_forecast_amount
     */
    private Long saleForecastAmount;

    /**
     * 是否促销(0是，1否)
     */
    private Byte isPromote;

    /**
     * 促销品采购方式
     */
    private String promoteProductBuyway;

    /**
     * 促销总金额(分)
     */
    private Integer promoteAmountTotal;

    /**
     * 登记意见
     */
    private String registNotes;

    /**
     * 活动投入实施说明
     */
    private String activityNotes;

    /**
     * 督查汇总意见
     */
    private String auditNotes;

    /**
     * 是否督查扣款
     */
    private int  idAuditWithhold;

	public Integer getId() {
		return id;
	}

	public void setId(Integer id) {
		this.id = id;
	}

	public String getFormNo() {
		return formNo;
	}

	public void setFormNo(String formNo) {
		this.formNo = formNo;
	}

	public String getFormType() {
		return formType;
	}

	public void setFormType(String formType) {
		this.formType = formType;
	}

	public Date getsDate() {
		return sDate;
	}

	public void setsDate(Date sDate) {
		this.sDate = sDate;
	}

	public Date geteDate() {
		return eDate;
	}

	public void seteDate(Date eDate) {
		this.eDate = eDate;
	}

	public String getKunnr() {
		return kunnr;
	}

	public void setKunnr(String kunnr) {
		this.kunnr = kunnr;
	}

	public String getLevel1Channel() {
		return level1Channel;
	}

	public void setLevel1Channel(String level1Channel) {
		this.level1Channel = level1Channel;
	}

	public String getLevel2Channel() {
		return level2Channel;
	}

	public void setLevel2Channel(String level2Channel) {
		this.level2Channel = level2Channel;
	}

	public String getSpart() {
		return spart;
	}

	public void setSpart(String spart) {
		this.spart = spart;
	}

	public String getActivityTypeCode() {
		return activityTypeCode;
	}

	public void setActivityTypeCode(String activityTypeCode) {
		this.activityTypeCode = activityTypeCode;
	}

	public String getActivityTypeName() {
		return activityTypeName;
	}

	public void setActivityTypeName(String activityTypeName) {
		this.activityTypeName = activityTypeName;
	}

	public String getActivityTypeCodeSub() {
		return activityTypeCodeSub;
	}

	public void setActivityTypeCodeSub(String activityTypeCodeSub) {
		this.activityTypeCodeSub = activityTypeCodeSub;
	}

	public String getActivityTypeNameSub() {
		return activityTypeNameSub;
	}

	public void setActivityTypeNameSub(String activityTypeNameSub) {
		this.activityTypeNameSub = activityTypeNameSub;
	}

	public String getDealerId() {
		return dealerId;
	}

	public void setDealerId(String dealerId) {
		this.dealerId = dealerId;
	}

	public String getDealerName() {
		return dealerName;
	}

	public void setDealerName(String dealerName) {
		this.dealerName = dealerName;
	}

	public String getDealerType() {
		return dealerType;
	}

	public void setDealerType(String dealerType) {
		this.dealerType = dealerType;
	}

	public String getRegionMkt() {
		return regionMkt;
	}

	public void setRegionMkt(String regionMkt) {
		this.regionMkt = regionMkt;
	}

	public String getZcmId() {
		return zcmId;
	}

	public void setZcmId(String zcmId) {
		this.zcmId = zcmId;
	}

	public String getZcmName() {
		return zcmName;
	}

	public void setZcmName(String zcmName) {
		this.zcmName = zcmName;
	}

	public String getSpeNotes() {
		return speNotes;
	}

	public void setSpeNotes(String speNotes) {
		this.speNotes = speNotes;
	}

	public Long getAddAssumeAmt() {
		return addAssumeAmt;
	}

	public void setAddAssumeAmt(Long addAssumeAmt) {
		this.addAssumeAmt = addAssumeAmt;
	}

	public Long getActivityAmount() {
		return activityAmount;
	}

	public void setActivityAmount(Long activityAmount) {
		this.activityAmount = activityAmount;
	}

	public Long getApplyAmount() {
		return applyAmount;
	}

	public void setApplyAmount(Long applyAmount) {
		this.applyAmount = applyAmount;
	}

	public Long getPayAmount() {
		return payAmount;
	}

	public void setPayAmount(Long payAmount) {
		this.payAmount = payAmount;
	}

	public Long getAuditAmount() {
		return auditAmount;
	}

	public void setAuditAmount(Long auditAmount) {
		this.auditAmount = auditAmount;
	}

	public Long getReviewAmount() {
		return reviewAmount;
	}

	public void setReviewAmount(Long reviewAmount) {
		this.reviewAmount = reviewAmount;
	}

	public Long getFinalAmount() {
		return finalAmount;
	}

	public void setFinalAmount(Long finalAmount) {
		this.finalAmount = finalAmount;
	}

	public String getPromoteType() {
		return promoteType;
	}

	public void setPromoteType(String promoteType) {
		this.promoteType = promoteType;
	}

	public int getIsIndividualPromote() {
		return isIndividualPromote;
	}

	public void setIsIndividualPromote(int isIndividualPromote) {
		this.isIndividualPromote = isIndividualPromote;
	}

	public String getChannel() {
		return channel;
	}

	public void setChannel(String channel) {
		this.channel = channel;
	}

	public String getAccountTreat() {
		return accountTreat;
	}

	public void setAccountTreat(String accountTreat) {
		this.accountTreat = accountTreat;
	}

	public String getEntryDealerId() {
		return entryDealerId;
	}

	public void setEntryDealerId(String entryDealerId) {
		this.entryDealerId = entryDealerId;
	}

	public String getEntryDealerName() {
		return entryDealerName;
	}

	public void setEntryDealerName(String entryDealerName) {
		this.entryDealerName = entryDealerName;
	}

	public int getIsPayment() {
		return isPayment;
	}

	public void setIsPayment(int isPayment) {
		this.isPayment = isPayment;
	}


	public Integer getStatus() {
		return status;
	}

	public void setStatus(Integer status) {
		this.status = status;
	}

	public String getCreateId() {
		return createId;
	}

	public void setCreateId(String createId) {
		this.createId = createId;
	}

	public String getCreateName() {
		return createName;
	}

	public void setCreateName(String createName) {
		this.createName = createName;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public String getModifyId() {
		return modifyId;
	}

	public void setModifyId(String modifyId) {
		this.modifyId = modifyId;
	}

	public String getModifyName() {
		return modifyName;
	}

	public void setModifyName(String modifyName) {
		this.modifyName = modifyName;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Integer getSaleForecastNum() {
		return saleForecastNum;
	}

	public void setSaleForecastNum(Integer saleForecastNum) {
		this.saleForecastNum = saleForecastNum;
	}

	public Long getSaleForecastAmount() {
		return saleForecastAmount;
	}

	public void setSaleForecastAmount(Long saleForecastAmount) {
		this.saleForecastAmount = saleForecastAmount;
	}

	public Byte getIsPromote() {
		return isPromote;
	}

	public void setIsPromote(Byte isPromote) {
		this.isPromote = isPromote;
	}

	public String getPromoteProductBuyway() {
		return promoteProductBuyway;
	}

	public void setPromoteProductBuyway(String promoteProductBuyway) {
		this.promoteProductBuyway = promoteProductBuyway;
	}

	public Integer getPromoteAmountTotal() {
		return promoteAmountTotal;
	}

	public void setPromoteAmountTotal(Integer promoteAmountTotal) {
		this.promoteAmountTotal = promoteAmountTotal;
	}

	public String getRegistNotes() {
		return registNotes;
	}

	public void setRegistNotes(String registNotes) {
		this.registNotes = registNotes;
	}

	public String getActivityNotes() {
		return activityNotes;
	}

	public void setActivityNotes(String activityNotes) {
		this.activityNotes = activityNotes;
	}

	public String getAuditNotes() {
		return auditNotes;
	}

	public void setAuditNotes(String auditNotes) {
		this.auditNotes = auditNotes;
	}

	public int getIdAuditWithhold() {
		return idAuditWithhold;
	}

	public void setIdAuditWithhold(int idAuditWithhold) {
		this.idAuditWithhold = idAuditWithhold;
	}

	public List<CostRegisterItemResVo> getItemList() {
		return itemList;
	}

	public void setItemList(List<CostRegisterItemResVo> itemList) {
		this.itemList = itemList;
	}

	/** 获取 标题*/
	public String getTitle() {
		return this.title;
	}

	/** 设置 标题*/
	public void setTitle(String title) {
		this.title = title;
	}

	/**
	 * 获取 开始日期
	 */
	public Date getSDate() {
		return this.sDate;
	}

	/**
	 * 设置 开始日期
	 */
	public void setSDate(Date sDate) {
		this.sDate = sDate;
	}

	/**
	 * 获取 结束日期
	 */
	public Date getEDate() {
		return this.eDate;
	}

	/**
	 * 设置 结束日期
	 */
	public void setEDate(Date eDate) {
		this.eDate = eDate;
	}
}
